NRCS_CoreVersion = "v1.2.3";
--
--    No Role Check Spam - Disables popup box when you have role selected
--    Copyright (C) 2013  Rachael Alexanderson
--
--    This program is free software: you can redistribute it and/or modify
--    it under the terms of the GNU General Public License as published by
--    the Free Software Foundation, either version 3 of the License, or
--    (at your option) any later version.
--
--    This program is distributed in the hope that it will be useful,
--    but WITHOUT ANY WARRANTY; without even the implied warranty of
--    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
--    GNU General Public License for more details.
--
--    You should have received a copy of the GNU General Public License
--    along with this program.  If not, see <http://www.gnu.org/licenses/>.
--

NRCS_Version = GetAddOnMetadata("NoRoleCheckSpam","Version");
if NRCS_Global == nil then NRCS_Global = {} end;

function NRCS_ImproperUpdate()
	local s_message = "You have not properly updated your add-ons. Please restart the game - No Role Check Spam will not work until you do.";
	message(s_message);
	DEFAULT_CHAT_FRAME:AddMessage(s_message);
end

if not ( NRCS_Version == NRCS_CoreVersion ) then
	NRCS_ImproperUpdate();
	return;
end

local frame = CreateFrame("FRAME", "NRCSFrame");
frame:RegisterEvent("PLAYER_ENTERING_WORLD");

NRCS_LastMessageTime = 0;
NRCS_Loaded = false;

NRCS_Option1 = false;
NRCS_Option2 = false;
NRCS_Option3 = false;

function NRCS_ReportToChat(text)
	-- I have intentionally put in a filter that will hopefully present messages only once
	-- every 15 seconds. I do not believe this addon should spam you unnecessarily, and it would
	-- otherwise be possible to spam this addon far more than you could spam people without it.
	-- So messages are blocked from appearing more than once every 15 seconds, to prevent this
	-- type of abuse. (Could be 60 seconds?)

	if ( NRCS_Global["Messages"] and (time() - NRCS_LastMessageTime) > 15 ) then
		NRCS_LastMessageTime = time();
		DEFAULT_CHAT_FRAME:AddMessage("|cff90ff90NRCS:|r "..text);
	end
end

local ReportToChat = NRCS_ReportToChat;

function NRCS_SysMessage(text)
	-- This is for when the addon absolutely must communicate with the player. Unfiltered.
	DEFAULT_CHAT_FRAME:AddMessage("|cffffff90NRCS:|r "..text);
end

local SysMessage = NRCS_SysMessage;

function NRCS_AutoSelectSpec()
	if ( GetSpecialization() == nil ) then
		SysMessage("Unable to automatically select role. You do not have a talent specialization.");
	else
		UnitSetRole("player",select(6,GetSpecializationInfo(GetSpecialization())));
		ReportToChat("Role Check was requested. Spec role automatically selected.");
	end
end


local function NRCSeventHandler(self, event, ...)
	-- Hook RolePollPopup's event handler. We rewrite our own!
	local canBeTank, canBeHealer, canBeDamager = UnitGetAvailableRoles("player");
	if ( event == "PLAYER_ENTERING_WORLD" ) then
		if NRCS_Loaded then return; end
		function NCRSRolePollPopup_OnEvent(self, event, ...)
			if ( event == "ROLE_POLL_BEGIN" ) then
				if ( NRCS_Global["Enable"] ) then
					if ( UnitGroupRolesAssigned("player") == "NONE" ) then
						if ( canBeTank == false and canBeHealer == false ) then
							-- DPS only. This is useful for rogues, hunters, warlocks,
							-- and mages who cannot set their roles otherwise.
							UnitSetRole("player","DAMAGER");
							ReportToChat("Role Check was requested. Non-hybrid role automatically selected.");
						else
							if ( NRCS_Global["AutoSpec"] ) then
								-- Set our role by current spec
								NRCS_AutoSelectSpec();
							else
								-- If we're playing a hybrid class, we'll comply with the
								-- role check as requested.
								if ( not RolePollPopup:IsShown() ) then
									RolePollPopup_Show(self);
								end
								ReportToChat("Role Check was requested. Currently on hybrid character - requesting your status.");
							end
						end
					elseif ( NRCS_Global["AutoSpec"] ) then
						-- Update our role by spec
						NRCS_AutoSelectSpec();
						ReportToChat("Role Check was requested. Spec role automatically updated.");
					else
						ReportToChat("Role Check was requested. Current role is already set; ignoring it.");
					end
				else
					-- Addon is disabled, pop up window unconditionally
					if ( not RolePollPopup:IsShown() ) then
						RolePollPopup_Show(self);
					end
				end
			end
		end
		RolePollPopup:SetScript("OnEvent",NCRSRolePollPopup_OnEvent);

		if ( NRCS_Global["Enable"] ) then ReportToChat(NRCS_Version.." loaded. Type /nrcs for options panel, or /nrcs help for a /command list."); end

		if ( NRCS_Global["Enable"] == nil ) then
			SysMessage("First time load. Type /nrcs for options panel, or /nrcs help for a /command list.");
			SysMessage("Please note that this addon by default supresses its own chat messages; this will be the last time you see this message until you erase its config.");
			SysMessage("If you wish to see what this addon is doing, type '/nrcs messages on'.");
			SysMessage("You are using version "..NRCS_Version);
			NRCS_Global["Enable"] = true;
		end

		if ( NRCS_Global["Enable"] == false ) then ReportToChat("Addon disabled."); end
		NRCS_Loaded = true;
	end
end

frame:SetScript("OnEvent", NRCSeventHandler);


